# ROCKET

`rocketumei812` is a Python library for ..........

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `ROCKET`.

```bash
pip install ROCKET
```

## Usage

```python
import ROCKET

# returns 'words'
ROCKET.rocket('word')

# returns 'geese'
ROCKET.rocket('goose')

# returns 'phenomenon'
ROCKET.rocket('phenomena')
```

## License
[MIT](https://choosealicense.com/licenses/mit/)